@@ -36,7 +36,7 @@ assert_file_exists = function(x, msg=NULL, class=NULL){
     msg = "Missing file{?s}: {.path {x[missing_files]}}"
   }
   if(any(missing_files)){
-    cli_abort(msg, call=parent.frame(), class=class)
+    cli_abort(msg, call=parent.frame(), .envir=parent.frame(), class=class)
   }
 }
 
@@ -137,5 +137,6 @@ is.Date = function (x) {
 #' @noRd
 #' @keywords internal
 is_edc_error = function(x){
-  inherits(x, "edc_error") || inherits(x, "edc_error_col") || inherits(x, "edc_error_data")
+  error_classes = c("error", "edc_error", "edc_error_col", "edc_error_data")
+  inherits(x, error_classes)
 }
